drop_privs

Function drop_privs 

fn drop_privs() -> Result<()>
Drop privileges to the real user and group of the process. If the process is not running with elevated privileges, this function is a no-op.